@@ -59,6 +59,9 @@ test_that("html - string are html encoded", {
 
   str_ <- flextable:::html_str(ft1)
   str_ <- gsub("<style>(.*)</style>", "", str_)
+  str_ <- gsub("<script>(.*)</script>", "", str_)
+  str_ <- gsub("<template id=\"[0-9a-z\\-]+\">", "", str_)
+  str_ <- gsub("</div></template(.*)", "", str_)
   doc <- read_xml(str_)
   text_ <- xml_text(xml_find_first(doc, "//tbody/tr/td/p/span"))
   expect_equal(text_, c("1 < 3") )
@@ -71,7 +74,10 @@ test_that("NA managment", {
 
   str_ <- flextable:::html_str(ft1)
   str_ <- gsub("<style>(.*)</style>", "", str_)
+  str_ <- gsub("<script>(.*)</script>", "", str_)
+  str_ <- gsub("<template id=\"[0-9a-z\\-]+\">", "", str_)
+  str_ <- gsub("</div></template(.*)", "", str_)
   doc <- read_xml(str_)
-  text_ <- xml_text(xml_find_all(doc, "/div/table/tbody/tr/td/p"))
+  text_ <- xml_text(xml_find_all(doc, "/table/tbody/tr/td/p"))
   expect_equal(text_, c("a", "") )
 })
